]> the.earth.li Git - onak.git/blobdiff - keydb.h
Configure basic onak.conf using autoconf info.
[onak.git] / keydb.h
diff --git a/keydb.h b/keydb.h
index 647916c9d42521473d4d5ba72a6e9a2bd79c6334..ae87ce385c561b2811d8324922d03aa86735cdf5 100644 (file)
--- a/keydb.h
+++ b/keydb.h
@@ -9,7 +9,6 @@
 #ifndef __KEYDB_H__
 #define __KEYDB_H__
 
-// #include <stdint.h>
 #include <inttypes.h>
 
 #include "keystructs.h"
 
 /**
  *     initdb - Initialize the key database.
+ *     @readonly: If we'll only be reading the DB, not writing to it.
  *
  *     This function should be called before any of the other functions in
  *     this file are called in order to allow the DB to be initialized ready
  *     for access.
  */
-void initdb(void);
+void initdb(bool readonly);
 
 /**
  *     cleanupdb - De-initialize the key database.
@@ -109,11 +109,13 @@ char *keyid2uid(uint64_t keyid);
 /**
  *     getkeysigs - Gets a linked list of the signatures on a key.
  *     @keyid: The keyid to get the sigs for.
+ *     @revoked: Is the key revoked?
  *
  *     This function gets the list of signatures on a key. Used for key 
*     indexing and doing stats bits.
  */
-struct ll *getkeysigs(uint64_t keyid);
+struct ll *getkeysigs(uint64_t keyid, bool *revoked);
 
 /**
  *     cached_getkeysigs - Gets the signatures on a key.
@@ -133,4 +135,16 @@ struct ll *cached_getkeysigs(uint64_t keyid);
  */
 uint64_t getfullkeyid(uint64_t keyid);
 
+/**
+ *     dumpdb - dump the key database
+ *     @filenamebase: The base filename to use for the dump.
+ *
+ *     Dumps the database into one or more files, which contain pure OpenPGP
+ *     that can be reimported into onak or gpg. filenamebase provides a base
+ *     file name for the dump; several files may be created, all of which will
+ *     begin with this string and then have a unique number and a .pgp
+ *     extension.
+ */
+int dumpdb(char *filenamebase);
+
 #endif /* __KEYDB_H__ */
@@ -109,11 +109,13 @@ char *keyid2uid(uint64_t keyid);
  *
  *     This function gets the list of signatures on a key. Used for key 
- *     indexing and doing stats bits.
+ *     indexing and doing stats bits. If revoked is non-NULL then if the key
+ *     is revoked it's set to true.
  */